@@ -67,6 +67,7 @@ TODO
 #include "connect.h"
 #include "config.h"
 #include "ctype.h"
+#include "stdbool.h"
 
 #define BLACKLIST_UNKNOWN_GTK_APPS 0
 
@@ -309,9 +310,9 @@ static gboolean sendMessage(GtkWidget *widget, Operation op, GSList **res, gchar
         if(writeBlock(kdialogdSocket, &o, 1) &&
            writeBlock(kdialogdSocket, (char *)&xid, 4) &&
            writeString(title) &&
-           (p1 ? writeString(p1) : TRUE) &&
-           (p2 ? writeString(p2) : TRUE) &&
-           (OP_FILE_SAVE==op ? writeBool(overWrite) : TRUE))
+           (p1 ? writeString(p1) : true) &&
+           (p2 ? writeString(p2) : true) &&
+           (OP_FILE_SAVE==op ? writeBool(overWrite) : true))
         {
             GtkWidget *dlg=gtk_dialog_new();
             KGtkData  d;
@@ -1432,7 +1433,7 @@ gint gtk_dialog_run(GtkDialog *dialog)
 #endif
                     openKdeDialog(GTK_WIDGET(dialog), title ? title : "",
                                   data->folder ? data->folder : "", NULL,
-                                  OP_FOLDER, &res, NULL, FALSE);
+                                  OP_FOLDER, &res, NULL, false);
                     folder=firstEntry(res);
 
                     if(folder)
